@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Jonathan Marten <jjm@keelhaul.me.uk>
+    SPDX-FileCopyrightText: 2014 Jonathan Marten <jjm@keelhaul.me.uk>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "categoryfilterproxymodel.h"
@@ -40,15 +27,14 @@ public:
     CategoryFilterProxyModelPrivate(CategoryFilterProxyModel *parent);
 
     QList<Tag::Id> filterIdList;
-    bool filterEnabled;
+    bool filterEnabled = false;
 
 private:
-    CategoryFilterProxyModel *q_ptr;
+    CategoryFilterProxyModel *const q_ptr;
 };
 
 CategoryFilterProxyModelPrivate::CategoryFilterProxyModelPrivate(CategoryFilterProxyModel *parent)
     : QObject()
-    , filterEnabled(false)
     , q_ptr(parent)
 {
 }
