@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Jonathan Marten <jjm@keelhaul.me.uk>
+    SPDX-FileCopyrightText: 2014 Jonathan Marten <jjm@keelhaul.me.uk>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "categoryselectwidget.h"
@@ -43,7 +30,7 @@ public:
     explicit CategorySelectWidgetPrivate(CategorySelectWidget *parent);
 
     Akonadi::TagModel *tagModel = nullptr;
-    int rowOffset;
+    int rowOffset = 0;
     QTimer *updateTimer = nullptr;
     KPIM::KCheckComboBox *checkCombo = nullptr;
 
@@ -64,15 +51,11 @@ public Q_SLOTS:
     void slotCheckedItemsTimer();
 
 private:
-    CategorySelectWidget *q_ptr;
+    CategorySelectWidget *const q_ptr;
 };
 
 CategorySelectWidgetPrivate::CategorySelectWidgetPrivate(CategorySelectWidget *parent)
     : QObject()
-    , tagModel(nullptr)
-    , rowOffset(0)
-    , updateTimer(nullptr)
-    , checkCombo(nullptr)
     , q_ptr(parent)
 {
 }
@@ -81,7 +64,7 @@ void CategorySelectWidgetPrivate::init()
 {
     Q_Q(CategorySelectWidget);
 
-    QHBoxLayout *hbox = new QHBoxLayout(q);
+    auto *hbox = new QHBoxLayout(q);
     hbox->setSpacing(0);
     hbox->setContentsMargins(0, 0, 0, 0);
 
@@ -92,7 +75,7 @@ void CategorySelectWidgetPrivate::init()
             this, &CategorySelectWidgetPrivate::slotCheckedItemsChanged);
     hbox->addWidget(checkCombo);
 
-    Monitor *monitor = new Monitor(this);
+    auto *monitor = new Monitor(this);
     monitor->setTypeMonitored(Monitor::Tags);
     tagModel = new Akonadi::TagModel(monitor, this);
 
@@ -108,7 +91,7 @@ void CategorySelectWidgetPrivate::init()
     updateTimer->setInterval(200);
     connect(updateTimer, &QTimer::timeout, this, &CategorySelectWidgetPrivate::slotCheckedItemsTimer);
 
-    QToolButton *but = new QToolButton(q);
+    auto *but = new QToolButton(q);
     but->setAutoRaise(true);
     but->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
     but->setToolTip(i18nc("@action:button", "Reset category filter"));
@@ -140,7 +123,7 @@ void CategorySelectWidgetPrivate::init()
 
 QStandardItemModel *CategorySelectWidgetPrivate::itemModel() const
 {
-    QStandardItemModel *m = qobject_cast<QStandardItemModel *>(checkCombo->model());
+    auto *m = qobject_cast<QStandardItemModel *>(checkCombo->model());
     Q_ASSERT(m != nullptr);
     return m;
 }
@@ -184,7 +167,7 @@ void CategorySelectWidgetPrivate::slotTagsInserted(const QModelIndex &parent, in
         //
         // FIXME: not tested (no way to create hierarchical tags at present)
         if (parent != QModelIndex()) {
-            const Tag::Id parentId = tagModel->data(idx, TagModel::IdRole).value<Tag::Id>();
+            const auto parentId = tagModel->data(idx, TagModel::IdRole).value<Tag::Id>();
             QModelIndexList matchList = itemModel()->match(itemModel()->index(0, 0), FILTER_ROLE,
                                                            parentId, 1,
                                                            Qt::MatchExactly | Qt::MatchRecursive);
