@@ -1,25 +1,9 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
-                     2009 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 1996-2002 Mirko Boehm <mirko@kde.org>
+  SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "detailledstyle.h"
@@ -45,7 +29,7 @@ static const char ContactHeaderForeColor[] = "ContactHeaderForeColor";
 static const char ContactHeaderBGColor[] = "ContactHeaderBGColor";
 
 struct ContactBlock {
-    typedef QVector<ContactBlock> List;
+    using List = QVector<ContactBlock>;
 
     QString header;
     QStringList entries;
@@ -85,7 +69,6 @@ QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSe
 
         const QString birthday = QLocale().toString(contact.birthday().date(), QLocale::ShortFormat);
 
-
         if (!contact.organization().isEmpty()) {
             ContactBlock block;
             block.header = i18n("Organization:");
@@ -186,11 +169,11 @@ QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSe
         content += QLatin1String("   <tr>\n");
         content += QLatin1String("    <td style=\"color: ") + settings.headerTextColor
                    +QLatin1String(";\" bgcolor=\"") + settings.headerBackgroundColor
-                   +QLatin1String("\" style=\"padding-left: 20px\">")
+                   +QLatin1String(R"(" style="padding-left: 20px">)")
                    +name +  QLatin1String("</td>\n");
         content += QLatin1String("    <td style=\"color: ") + settings.headerTextColor
-                   +QLatin1String(";\" align=\"right\" bgcolor=\"") + settings.headerBackgroundColor
-                   +QLatin1String("\" style=\"padding-right: 20px\">")
+                   +QLatin1String(R"(;" align="right" bgcolor=")") + settings.headerBackgroundColor
+                   +QLatin1String(R"(" style="padding-right: 20px">)")
                    +birthday + QLatin1String("</td>\n");
         content += QLatin1String("   </tr>\n");
 
@@ -260,7 +243,7 @@ DetailledPrintStyle::DetailledPrintStyle(PrintingWizard *parent)
     , mPageAppearance(new AppearancePage(parent))
 {
     setPreview(QStringLiteral("detailed-style.png"));
-    setPreferredSortOptions(KAddressBookImportExport::KAddressBookImportExportContactFields::FormattedName, Qt::AscendingOrder);
+    setPreferredSortOptions(KAddressBookImportExport::ContactFields::FormattedName, Qt::AscendingOrder);
 
     addPage(mPageAppearance, i18n("Detailed Print Style - Appearance"));
 
